module.exports = defineTest({
	description: 'handles manually defined iterators'
});
